import { useState } from 'react'
import { NavLink } from 'react-router'
import newsBanner from '~/images/news-banner.png'
import newsItem from '~/images/news-item.png'
import newsItem02 from '~/images/news-item-02.png'
import arrowRightDoublePrimary from '~/images/arrow-right-double-primary.svg'
import { ROUTES } from '~/routes'
import pageBg from '~/images/page-bg.png'

export default function News() {
  const [currentTab, setCurrentTab] = useState(0)

  const tabs = ['Haberler', 'Kampanyalar']

  const tabContents = [
    {
      items: [
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('1')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('2')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('2')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('3')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('4')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('5')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('6')
        },
        {
          imageUrl: newsItem,
          url: ROUTES.NEW_DETAIL('7')
        }
      ]
    },
    {
      items: [
        {
          imageUrl: newsItem02,
          url: ROUTES.NEW_DETAIL + '/1'
        },
        {
          imageUrl: newsItem02,
          url: ROUTES.NEW_DETAIL + '/2'
        }
      ]
    }
  ]

  return (
    <div
      style={{
        backgroundImage: `url(${pageBg})`,
        backgroundSize: 'contain',
        backgroundPosition: 'top',
        backgroundRepeat: 'no-repeat'
      }}
    >
      <div className="relative">
        <div className="absolute inset-0 z-10 bg-secondary mix-blend-color opacity-70" />
        <img src={newsBanner} className="w-full" alt="" />
      </div>
      <div className="container mx-auto px-4 -mt-16">
        <div className="flex justify-between relative -mx-2 lg:-mx-4 z-30">
          <aside className="w-2/5 sticky top-4 h-screen px-2 lg:px-4 space-y-4 lg:space-y-6">
            <div className="bg-white text-center lg:text-3xl font-bold border border-gray-200 p-2 lg:p-4 rounded-2xl">
              Haberler & Kampanyalar
            </div>
            {tabs.map((tab, i) => (
              <div key={i}>
                <span
                  className="inline-flex items-center gap-2 lg:gap-4 group cursor-pointer"
                  onClick={() => setCurrentTab(i)}
                >
                  <svg
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    xmlns="http://www.w3.org/2000/svg"
                    className={`stroke-navy group-hover:stroke-secondary mt-1 ${i === currentTab ? 'stroke-secondary' : ''}`}
                  >
                    <path
                      d="M17 8L21 12M21 12L17 16M21 12L3 12"
                      stroke-width="2"
                      stroke-linecap="round"
                      stroke-linejoin="round"
                    />
                  </svg>
                  <span
                    className={`font-bold lg:text-xl group-hover:text-secondary ${i === currentTab ? 'text-secondary' : ''}`}
                  >
                    {tab}
                  </span>
                </span>
              </div>
            ))}
          </aside>
          <div className="w-3/5 px-2 lg:px-4">
            <div className="max-w-lg 2xl:max-w-3xl ml-auto space-y-4 lg:space-y-8 grid grid-cols-1 2xl:grid-cols-2 gap-4 lg:gap-8">
              {tabContents[currentTab].items.map((item, i) => (
                <div key={i}>
                  <NavLink to={item.url}>
                    <div className="bg-primary p-3 rounded-2xl relative">
                      <img src={item.imageUrl} alt="" className="rounded-2xl w-full" />
                      <span className="md:w-[280px] md:h-[60px] px-4 text-center bg-white border-4 border-primary rounded-tl-full absolute right-0 bottom-0 text-primary font-medium text-lg flex items-center justify-center gap-2">
                        <span className="pb-1">Detayı Gör</span>
                        <img src={arrowRightDoublePrimary} width={24} height={24} alt="" />
                      </span>
                    </div>
                  </NavLink>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}
